@@ -8,6 +8,7 @@
 #'   \item{Minor formatting for units: }{For conformance to WQX, e.g., ppt is changed to ppth, s.u. is changed to NA in \code{uom}}
 #'   \item{Convert Parameter: }{All parameters are converted to \code{Simple Parameter} in \code{\link{paramsMWR}} as needed}
 #'   \item{Remove unicode: }{Remove or replace unicode characters with those that can be used in logical expressions in \code{\link{qcMWRacc}}, e.g., replace \eqn{\geq} with \eqn{>=}}
+#'   \item{Convert limits to numeric: }{Convert \code{MDL} and \code{UQL} columns to numeric}
 #' }
 #' 
 #' @return A formatted data frame of the data quality objectives file for accuracy
@@ -17,7 +18,8 @@
 #' @examples
 #' accpth <- system.file('extdata/ExampleDQOAccuracy.xlsx', package = 'MassWateR')
 #' 
-#' accdat <- readxl::read_excel(accpth, na = c('NA', 'na', '')) 
+#' accdat <- readxl::read_excel(accpth, na = c('NA', ''))
+#' accdat <- dplyr::mutate(accdat, dplyr::across(-c(`Value Range`), ~ dplyr::na_if(.x, 'na')))
 #' 
 #' formMWRacc(accdat)
 formMWRacc <- function(accdat){
@@ -37,11 +39,12 @@ formMWRacc <- function(accdat){
         `Parameter` %in% paramsMWR$`WQX Parameter`, 
         paramsMWR$`Simple Parameter`[match(`Parameter`, paramsMWR$`WQX Parameter`)], 
         `Parameter`
-      )
-    ) %>% 
-    dplyr::mutate_at(vars(-Parameter, -uom, -MDL, -UQL), function(x) gsub('\u00b1', '', x)) %>%
-    dplyr::mutate_at(vars(-Parameter, -uom, -MDL, -UQL), function(x) gsub('\u2264', '<=', x)) %>%
-    dplyr::mutate_at(vars(-Parameter, -uom, -MDL, -UQL), function(x) gsub('\u2265', '>=', x))
+        ),
+      dplyr::across(-c(Parameter, uom, MDL, UQL), function(x) gsub('\u00b1', '', x)),
+      dplyr::across(-c(Parameter, uom, MDL, UQL), function(x) gsub('\u2264', '<=', x)),
+      dplyr::across(-c(Parameter, uom, MDL, UQL), function(x) gsub('\u2265', '>=', x)), 
+      dplyr::across(c(MDL, UQL), as.numeric)
+    )
   
   return(out)
   
