@@ -37,7 +37,7 @@ globalVariables(c("Activity Start Date", "Activity Start Time", "QC Reference Va
                   "Field Duplicate2", "Field Duplicatena", "Lab Blankna", "Lab Duplicate2",
                   "Lab Duplicatena", "Sampling Method Context", "Spike/Check Accuracy2", 
                   "Spike/Check Accuracyna", "Result Detection/Quantitation Limit Value",
-                  "Local Record ID", "Activity ID User Supplied"
+                  "Local Record ID", "Record ID User Supplied", "hr", "mn", "ispm"
                   ))
 
 #' @importFrom stats IQR na.omit quantile t.test
