@@ -3,25 +3,31 @@ library(dplyr)
 
 # results data
 respth <- system.file('extdata/ExampleResults.xlsx', package = 'MassWateR')
-resdat <- suppressWarnings(readxl::read_excel(respth, na = c('NA', 'na', ''), guess_max = Inf)) %>% 
+resdatchk <- suppressWarnings(readxl::read_excel(respth, na = c('NA', 'na', ''), guess_max = Inf)) %>% 
   dplyr::mutate_if(function(x) !lubridate::is.POSIXct(x), as.character)
+resdat <- readMWRresults(respth, runchk = F, warn = F)
 
 # dqo accuracy data
 accpth <- system.file('extdata/ExampleDQOAccuracy.xlsx', package = 'MassWateR')
-accdat <- readxl::read_excel(accpth, na = c('NA', 'na', ''))
+accdatchk <- readxl::read_excel(accpth, na = c('NA', ''))
+accdatchk <- mutate(accdatchk, across(-c(`Value Range`), ~ na_if(.x, 'na')))
+accdat <- readMWRacc(accpth, runchk = F, warn = F)
 
 # dqo completeness data
 frecompth <- system.file('extdata/ExampleDQOFrequencyCompleteness.xlsx', package = 'MassWateR')
-frecomdat <- suppressMessages(readxl::read_excel(frecompth, 
+frecomdatchk <- suppressMessages(readxl::read_excel(frecompth, 
                           skip = 1, na = c('NA', 'na', ''), 
                           col_types = c('text', 'numeric', 'numeric', 'numeric', 'numeric', 'numeric', 'numeric')
 )) %>% 
   rename(`% Completeness` = `...7`)
+frecomdat <- readMWRfrecom(frecompth, runchk = F, warn = F)
 
 # site metadata
 sitpth <- system.file('extdata/ExampleSites.xlsx', package = 'MassWateR')
-sitdat <- readxl::read_excel(sitpth, na = c('NA', 'na', ''))
+sitdatchk <- readxl::read_excel(sitpth, na = c('NA', 'na', ''))
+sitdat <- readMWRsites(sitpth, runchk = F) 
 
 # wqx metadata
 wqxpth <- system.file('extdata/ExampleWQX.xlsx', package = 'MassWateR')
-wqxdat <- readxl::read_excel(wqxpth, na = c('NA', 'na', ''), col_types = 'text')
+wqxdatchk <- readxl::read_excel(wqxpth, na = c('NA', 'na', ''), col_types = 'text')
+wqxdat <- readMWRwqx(wqxpth, runchk = F, warn = F)
